=======
Authors
=======

This application is developed and maintained by `miigotu <https://github.com/miigotu>`_.

Development Lead
----------------

* Dustyn Gibson <miigotu@gmail.com>

Contributors
------------

* TBD
